@@ -19,7 +19,7 @@ import warnings
 import webbrowser
 
 import requests
-from .util import CLIENT_CREDS_ENV_VARS, get_host_port
+from .constants import CLIENT_CREDS_ENV_VARS
 from .exceptions import SpotifyException
 
 import re
@@ -410,12 +410,12 @@ class SpotifyOAuth(SpotifyAuthBase):
         self._open_auth_url()
         server.handle_request()
 
-        if self.state is not None and server.state != self.state:
+        if self.state and server.state != self.state:
             raise SpotifyStateError(self.state, server.state)
 
-        if server.auth_code is not None:
+        if server.auth_code:
             return server.auth_code
-        elif server.error is not None:
+        elif server.error:
             raise SpotifyOauthError("Received error from OAuth server: {}".format(server.error))
         else:
             raise SpotifyOauthError("Server listening on localhost has not been accessed")
@@ -1206,6 +1206,17 @@ window.close()
         return
 
 
+def get_host_port(netloc):
+    if ":" in netloc:
+        host, port = netloc.split(":", 1)
+        port = int(port)
+    else:
+        host = netloc
+        port = None
+
+    return host, port
+
+
 def start_local_http_server(port, handler=RequestHandler):
     server = HTTPServer(("127.0.0.1", port), handler)
     server.allow_reuse_address = True
